@@ -16,14 +16,14 @@
 #ifndef LIBRADIUS_H
 #define LIBRADIUS_H
 /*
- * $Id: e5f2251949b5f9d2525da8303b0cbbfd16a2872a $
+ * $Id: 777927edb325aded5696ddfcb7fe732c91017c46 $
  *
  * @file libradius.h
  * @brief Structures and prototypes for the radius library.
  *
  * @copyright 1999-2014 The FreeRADIUS server project
  */
-RCSIDH(libradius_h, "$Id: e5f2251949b5f9d2525da8303b0cbbfd16a2872a $")
+RCSIDH(libradius_h, "$Id: 777927edb325aded5696ddfcb7fe732c91017c46 $")
 
 /*
  *  Compiler hinting macros.  Included here for 3rd party consumers
@@ -407,6 +407,9 @@ typedef struct radius_packet {
 	size_t			partial;
 	int			proto;
 #endif
+#ifdef WITH_RADIUSV11
+	bool			radiusv11;
+#endif
 } RADIUS_PACKET;
 
 typedef enum {
@@ -427,6 +430,16 @@ typedef enum {
 	DECODE_FAIL_MAX
 } decode_fail_t;
 
+#ifdef WITH_RADIUSV11
+typedef enum {
+       FR_RADIUSV11_FORBID = 0,
+       FR_RADIUSV11_ALLOW,
+       FR_RADIUSV11_REQUIRE,
+} fr_radiusv11_t;
+
+extern const FR_NAME_NUMBER radiusv11_types[];
+#endif
+
 /*
  *	Version check.
  */
@@ -531,6 +544,8 @@ RADIUS_PACKET	*rad_alloc_reply(TALLOC_CTX *ctx, RADIUS_PACKET *);
 RADIUS_PACKET *rad_copy_packet(TALLOC_CTX *ctx, RADIUS_PACKET const *in);
 
 void		rad_free(RADIUS_PACKET **);
+
+#ifndef WITH_RADIUSV11_ONLY
 int		rad_pwencode(char *encpw, size_t *len, char const *secret,
 			     uint8_t const *vector);
 int		rad_pwdecode(char *encpw, size_t len, char const *secret,
@@ -543,6 +558,7 @@ ssize_t		rad_tunnel_pwdecode(uint8_t *encpw, size_t *len,
 				    char const *secret, uint8_t const *vector);
 int		rad_chap_encode(RADIUS_PACKET *packet, uint8_t *output,
 				int id, VALUE_PAIR *password);
+#endif
 
 int		rad_attr_ok(RADIUS_PACKET const *packet, RADIUS_PACKET const *original,
 			    DICT_ATTR *da, uint8_t const *data, size_t length);
