@@ -1,7 +1,7 @@
 /*
  * misc.c	Various miscellaneous functions.
  *
- * Version:	$Id: 36378ec40c9387da9b4c4c1081aeaa93e59a7142 $
+ * Version:	$Id: b80b9ce468528f05b4dc2af26250431583d5282e $
  *
  *   This library is free software; you can redistribute it and/or
  *   modify it under the terms of the GNU Lesser General Public
@@ -20,7 +20,7 @@
  * Copyright 2000,2006  The FreeRADIUS server project
  */
 
-RCSID("$Id: 36378ec40c9387da9b4c4c1081aeaa93e59a7142 $")
+RCSID("$Id: b80b9ce468528f05b4dc2af26250431583d5282e $")
 
 #include <freeradius-devel/libradius.h>
 
@@ -1254,6 +1254,7 @@ struct in_addr fr_inaddr_mask(struct in_addr const *ipaddr, uint8_t prefix)
 struct in6_addr fr_in6addr_mask(struct in6_addr const *ipaddr, uint8_t prefix)
 {
 	uint64_t const *p = (uint64_t const *) ipaddr;
+	uint64_t addr;					/* Needed for alignment */
 	uint64_t ret[2], *o = ret;
 
 	if (prefix > 128) prefix = 128;
@@ -1263,14 +1264,17 @@ struct in6_addr fr_in6addr_mask(struct in6_addr const *ipaddr, uint8_t prefix)
 
 	if (prefix >= 64) {
 		prefix -= 64;
-		*o++ = 0xffffffffffffffffULL & *p++;	/* lhs portion masked */
+		memcpy(&addr, p, sizeof(addr));		/* Needed for aligned access (ubsan) */
+		*o++ = 0xffffffffffffffffULL & addr;	/* lhs portion masked */
+		p++;
 	} else {
 		ret[1] = 0;				/* rhs portion zeroed */
 	}
 
 	/* Max left shift is 63 else we get overflow */
 	if (prefix > 0) {
-		*o = htonll(~((uint64_t)(0x0000000000000001ULL << (64 - prefix)) - 1)) & *p;
+		memcpy(&addr, p, sizeof(addr));		/* Needed for aligned access (ubsan) */
+		*o = htonll(~((uint64_t)(0x0000000000000001ULL << (64 - prefix)) - 1)) & addr;
 	} else {
 		*o = 0;
 	}
